==> familia_0.1.tar.gz: familia/src/file/name.cpp <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#include "name.h"

Name::Name() {
}

Name::~Name() {
}

void Name::setFirst(_String str) {
  first = str;
}

void Name::setMiddle(_String str) {
  middle = str;
}

void Name::setLast(_String str) {
  last = str;
}

Name::_String Name::getFirst() {
  return first;  
}

Name::_String Name::getMiddle() {
  return middle;
}

Name::_String Name::getLast() {
  return last;
}

==> familia_0.1.2.tar.gz: familia/src/file/name.cpp <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#include "name.h"

Name::Name() {
}

Name::~Name() {
  first.clear();
  middle.clear();
  last.clear();
}

void Name::setFirst(String str) {
  first = str;
}

void Name::setMiddle(String str) {
  middle = str;
}

void Name::setLast(String str) {
  last = str;
}

Name::String Name::getFirst() {
  return first;  
}

Name::String Name::getMiddle() {
  return middle;
}

Name::String Name::getLast() {
  return last;
}
